asn1_* renamed into asn_*


git-svn-id: https://asn1c.svn.sourceforge.net/svnroot/asn1c/trunk@446 59561ff5-6e30-0410-9f3c-9617f08c8826
diff --git a/skeletons/constr_SET.h b/skeletons/constr_SET.h
index 17fb613..8f9b265 100644
--- a/skeletons/constr_SET.h
+++ b/skeletons/constr_SET.h
@@ -8,18 +8,18 @@
 #include <asn_application.h>
 
 
-typedef struct asn1_SET_specifics_s {
+typedef struct asn_SET_specifics_s {
 	/*
 	 * Target structure description.
 	 */
 	int struct_size;	/* Size of the target structure. */
-	int ctx_offset;		/* Offset of the ber_dec_ctx_t member */
+	int ctx_offset;		/* Offset of the asn_struct_ctx_t member */
 	int pres_offset;	/* Offset of _presence_map member */
 
 	/*
 	 * Tags to members mapping table (sorted).
 	 */
-	asn1_TYPE_tag2member_t *tag2el;
+	asn_TYPE_tag2member_t *tag2el;
 	int tag2el_count;
 
 	/*
@@ -27,7 +27,7 @@
 	 */
 	int extensible;				/* Whether SET is extensible */
 	unsigned int *_mandatory_elements;	/* Bitmask of mandatory ones */
-} asn1_SET_specifics_t;
+} asn_SET_specifics_t;
 
 /*
  * A set specialized functions dealing with the SET type.